@@ -19,7 +19,6 @@ char *fake = N_("Absolute value");
 char *fake = N_("Replace very small number with zero");
 char *fake = N_("Return the fractional part of a number");
 char *fake = N_("Division w/o remainder");
-char *fake = N_("Check if argument is a gaussian integer");
 char *fake = N_("Return the sign (-1,0,1)");
 char *fake = N_("Logarithm of any base (calls DiscreteLog if in modulo mode), if base is not given, e is used");
 char *fake = N_("The arccos (inverse cos) function");
@@ -54,6 +53,7 @@ char *fake = N_("Find the first primitive element in F_q (q must be a prime)");
 char *fake = N_("Find a random primitive element in F_q (q must be a prime)");
 char *fake = N_("Compute discrete log base b of n in F_q (q a prime) using the factor base S.  S should be a column of primes possibly with second column precalculated by IndexCalculusPrecalculation.");
 char *fake = N_("Run the precalculation step of IndexCalculus for logarithms base b in F_q (q a prime) for the factor base S (where S is a column vector of primes).  The logs will be precalculated and returned in the second column.");
+char *fake = N_("Test if Mp is a Mersenne prime using a table");
 char *fake = N_("Tests if a rational number is a perfect power");
 char *fake = N_("Check if g is primitive in F_q, where q is a prime.  If q is not prime results are bogus.");
 char *fake = N_("Check if g is primitive in F_q, where q is a prime and f is a vector of prime factors of q-1.  If q is not prime results are bogus.");
@@ -62,6 +62,7 @@ char *fake = N_("Test if n is a strong pseudoprime to base b but not a prime");
 char *fake = N_("Return the residue of a mod n with the least absolute value (in the interval -n/2 to n/2)");
 char *fake = N_("Test if Mp is a Mersenne prime using the Lucas-Lehmer test");
 char *fake = N_("Return all maximal prime power factors of a number");
+char *fake = N_("Vector with the known Mersenne prime exponents");
 char *fake = N_("Return the Moebius mu function evaluated in n");
 char *fake = N_("Returns the padic valuation (number of trailing zeros in base p).");
 char *fake = N_("Compute a^b mod m");
@@ -77,12 +78,9 @@ char *fake = N_("Calculate the kth compund matrix of A");
 char *fake = N_("Delete a column of a matrix");
 char *fake = N_("Delete a row of a matrix");
 char *fake = N_("Get the dot product of two vectors (no conjugates)");
-char *fake = N_("Is a matrix diagonal");
-char *fake = N_("Is a matrix lower triangular");
-char *fake = N_("Is a matrix upper triangular");
-char *fake = N_("Is argument a horizontal or a vertical vector");
 char *fake = N_("Zero out entries above the diagonal");
 char *fake = N_("Make diagonal matrix from a vector");
+char *fake = N_("Make column vector out of matrix by putting columns above each other");
 char *fake = N_("Calculate the product of all elements in a matrix");
 char *fake = N_("Calculate the sum of all elements in a matrix");
 char *fake = N_("Calculate the sum of squares of all elements in a matrix");
@@ -101,6 +99,7 @@ char *fake = N_("Return a function that evaluates two vectors with respect to th
 char *fake = N_("Get the characteristic polynomial as a vector");
 char *fake = N_("Get the characteristic polynomial as a function");
 char *fake = N_("Get a basis matrix for the columnspace of a matrix");
+char *fake = N_("Return the commutation matrix K(m,n) which is the unique m*n by m*n matrix such that K(m,n) * MakeVector(A) = MakeVector(A.') for all m by n matrices A.");
 char *fake = N_("Companion matrix of a polynomial (as vector)");
 char *fake = N_("Conjugate transpose of a matrix (adjoint)");
 char *fake = N_("Calculate convolution of two horizontal vectors");
@@ -109,7 +108,8 @@ char *fake = N_("CrossProduct of two vectors in R^3");
 char *fake = N_("Get the determinantal divisors of an integer matrix (not its characteristic)");
 char *fake = N_("Direct sum of matrices");
 char *fake = N_("Direct sum of a vector of matrices");
-char *fake = N_("Get the eigenvalues of a matrix (Currently only for 2x2 and triangular matrices)");
+char *fake = N_("Get the eigenvalues of a matrix (Currently only for up to 4x4 or triangular matrices)");
+char *fake = N_("Get the eigenvalues and eigenvectors of a matrix (Currently only for up to 2x2 matrices)");
 char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to inner product given by B (if not given use hermitian product)");
 char *fake = N_("Hankel matrix");
 char *fake = N_("Hilbert matrix of order n");
@@ -122,6 +122,8 @@ char *fake = N_("Test if a vector is in a subspace");
 char *fake = N_("Is a matrix (or number) invertible (Integer matrix is invertible iff it's invertible over the integers)");
 char *fake = N_("Is a matrix (or number) invertible over a field");
 char *fake = N_("Is a matrix normal");
+char *fake = N_("Is a matrix positive definite");
+char *fake = N_("Is a matrix positive semidefinite");
 char *fake = N_("Is a matrix skew-hermitian");
 char *fake = N_("Is a matrix unitary");
 char *fake = N_("Get the jordan block corresponding to lambda and n");
@@ -130,14 +132,13 @@ char *fake = N_("Get the LU decomposition of A and store the result in the L and
 char *fake = N_("Get the i-j minor of a matrix");
 char *fake = N_("Return the columns that are not the pivot columns of a matrix");
 char *fake = N_("Get the p Norm (or 2 Norm if no p is supplied) of a vector");
-char *fake = N_("Get the nullspace of a matrix");
 char *fake = N_("Get the nullity of a matrix");
 char *fake = N_("Get the orthogonal complement of the columnspace");
-char *fake = N_("Return pivot columns of a matrix, that is columns which have a leading 1 in rref form, also returns the row where they occur");
 char *fake = N_("Projection of vector v onto subspace W given a sesquilinear form B (if not given use hermitian product)");
 char *fake = N_("Get the QR decomposition of A, returns R and Q can be a reference");
-char *fake = N_("Return the Raleigh Quotient of a matrix and a vector");
 char *fake = N_("Get the rank of a matrix");
+char *fake = N_("Return the Rayleigh quotient of a matrix and a vector");
+char *fake = N_("Compute an eigenvalue using the Rayleigh Quotient Iteration method until we are epsilon from eigenvalue or for maxiter iterations");
 char *fake = N_("Rosser matrix, a classic symmetric eigenvalue test problem");
 char *fake = N_("Rotation around origin in R^2");
 char *fake = N_("Rotation around origin in R^3 about the x-axis");
@@ -148,6 +149,7 @@ char *fake = N_("Evaluate (v,w) with respect to the sesquilinear form given by t
 char *fake = N_("Return a function that evaluates two vectors with respect to the sesquilinear form given by A");
 char *fake = N_("Smith Normal Form for fields (will end up with 1's on the diagonal)");
 char *fake = N_("Smith Normal Form for square integer matrices (not its characteristic)");
+char *fake = N_("Return the Toeplitz matrix constructed given the first column c and (optionally) the first row r.");
 char *fake = N_("Calculate the trace of a matrix");
 char *fake = N_("Transpose of a matrix");
 char *fake = N_("Return the Vandermonde matrix");
@@ -161,17 +163,20 @@ char *fake = N_("Get n'th catalan number");
 char *fake = N_("Double factorial: n(n-2)(n-4)...");
 char *fake = N_("Factorial: n(n-1)(n-2)...");
 char *fake = N_("Falling factorial: (n)_k = n(n-1)...(n-(k-1))");
-char *fake = N_("Calculate n'th fibbonachi number");
+char *fake = N_("Calculate n'th Fibonacci number");
+char *fake = N_("Calculate the Frobenius number for a coin problem");
 char *fake = N_("Galois matrix given a linear combining rule (a_1*x_+...+a_n*x_n=x_(n+1))");
+char *fake = N_("Use greedy algorithm to find c, for c . v = n.  (v must be sorted)");
 char *fake = N_("Harmonic Number, the nth harmonic number of order r");
 char *fake = N_("Hofstadter's function q(n) defined by q(1)=1, q(2)=1, q(n)=q(n-q(n-1))+q(n-q(n-2))");
 char *fake = N_("Compute linear recursive sequence using galois stepping");
 char *fake = N_("Calculate multinomial coefficients");
 char *fake = N_("Get the pascal's triangle as a matrix");
-char *fake = N_("(Puchhammer) Rising factorial: (n)_k = n(n+1)...(n+(k-1))");
+char *fake = N_("(Pochhammer) Rising factorial: (n)_k = n(n+1)...(n+(k-1))");
+char *fake = N_("Stirling number of the first kind");
+char *fake = N_("Stirling number of the second kind");
 char *fake = N_("Subfactorial: n! times sum_{k=1}^n (-1)^k/k!");
 char *fake = N_("Calculate the nth triangular number");
-char *fake = N_("Calculate combinations (binomial coefficient)");
 char *fake = N_("Calculate permutations");
 char *fake = N_("Integration of f by Composite Simpson's Rule on the interval [a,b] with the number of steps calculated by the fourth derivative bound and the desired tolerance");
 char *fake = N_("Attempt to calculate derivative by trying first symbolically and then numerically");
@@ -212,11 +217,14 @@ char *fake = N_("The unit step function = 0 for x<0, 1 otherwise.  This is the i
 char *fake = N_("The cis function, that is cos(x)+i*sin(x)");
 char *fake = N_("Convert degrees to radians");
 char *fake = N_("Convert radians to degrees");
+char *fake = N_("Find roots of a cubic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
 char *fake = N_("Find root of a function using the bisection method");
 char *fake = N_("Find root of a function using the method of false position");
 char *fake = N_("Find root of a function using the Muller's method");
 char *fake = N_("Find root of a function using the secant method");
+char *fake = N_("Find roots of a polynomial (given as vector of coefficients)");
+char *fake = N_("Find roots of a quartic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
 char *fake = N_("Calculate average of an entire matrix");
 char *fake = N_("Integral of the GaussFunction from 0 to x (area under the normal curve)");
