@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2007 Jiri (George) Lebl
+ * Copyright (C) 1997-2008 Jiri (George) Lebl
  *
  * Author: Jiri (George) Lebl
  *
@@ -20,6 +20,7 @@
  */
 #include "config.h"
 
+#include <errno.h>
 #include <stdlib.h>
 #include <dirent.h>
 #include <unistd.h>
@@ -1252,6 +1253,64 @@ matrix_chop_p (GelMatrixW *m, int chop_when)
 	return FALSE;
 }
 
+static void
+append_func (GelOutput *gelo, GelEFunc *f)
+{
+	GSList *li;
+
+	if G_UNLIKELY (f == NULL) {
+		gel_errorout (_("NULL function!"));
+		gel_output_string(gelo,"(?)");
+		return;
+	}
+	if(f->type==GEL_BUILTIN_FUNC) {
+		gel_output_string(gelo,"(<builtin function>)");
+		return;
+	}
+
+	gel_output_string(gelo,"(`(");
+
+	for(li=f->named_args; li!=NULL; li=g_slist_next(li)) {
+		GelToken *id = li->data;
+		if (li != f->named_args)
+			gel_output_string (gelo, ",");
+		gel_output_string(gelo,id->token);
+	}
+
+	if (f->vararg)
+		gel_output_string (gelo, "...");
+
+	if G_LIKELY (f->type==GEL_USER_FUNC) {
+		gel_output_string(gelo,")=");
+		D_ENSURE_USER_BODY (f);
+		if (f->extra_dict != NULL) {
+			GSList *li;
+			gel_output_string(gelo,"(");
+			for (li = f->extra_dict; li != NULL; li = li->next) {
+				GelEFunc *ff = li->data;
+				gel_output_string (gelo, ff->id->token);
+				gel_output_string (gelo, "=");
+				if (ff->type == GEL_VARIABLE_FUNC) {
+					gel_print_etree (gelo, ff->data.user, FALSE);
+				} else {
+					append_func (gelo, ff);
+				}
+				gel_output_string (gelo, ";");
+			}
+		}
+		gel_print_etree (gelo, f->data.user, FALSE);
+		if (f->extra_dict != NULL) {
+			gel_output_string(gelo,")");
+		}
+		gel_output_string(gelo,")");
+	} else {
+		/*variable and reference functions should
+		  never be in the etree*/
+		gel_errorout (_("Unexpected function type!"));
+		gel_output_string(gelo,")(?))");
+	}
+}
+
 /*make a string representation of an expression*/
 void
 gel_print_etree (GelOutput *gelo,
@@ -1340,46 +1399,8 @@ gel_print_etree (GelOutput *gelo,
 		gel_output_string(gelo,"\"");
 		break;
 	case FUNCTION_NODE:
-		{
-			GSList *li;
-			GelEFunc *f;
-			
-			f = n->func.func;
-			if G_UNLIKELY (f == NULL) {
-				gel_errorout (_("NULL function!"));
-				gel_output_string(gelo,"(?)");
-				break;
-			}
-			if(f->type==GEL_BUILTIN_FUNC) {
-				gel_output_string(gelo,"(<builtin function>)");
-				break;
-			}
-
-			gel_output_string(gelo,"(`(");
-
-			for(li=f->named_args; li!=NULL; li=g_slist_next(li)) {
-				GelToken *id = li->data;
-				if(li!=f->named_args)
-					gel_output_string(gelo,",");
-				gel_output_string(gelo,id->token);
-			}
-
-			if (f->vararg)
-				gel_output_string (gelo, "...");
-
-			if G_LIKELY (f->type==GEL_USER_FUNC) {
-				gel_output_string(gelo,")=");
-				D_ENSURE_USER_BODY (f);
-				gel_print_etree (gelo, f->data.user, FALSE);
-				gel_output_string(gelo,")");
-			} else {
-				/*variable and reference functions should
-				  never be in the etree*/
-				gel_errorout (_("Unexpected function type!"));
-				gel_output_string(gelo,")(?))");
-			}
-			break;
-		}
+		append_func (gelo, n->func.func);
+		break;
 	case COMPARISON_NODE:
 		appendcomp(gelo,n);
 		break;
@@ -1544,7 +1565,8 @@ pretty_print_value_normal (GelOutput *gelo, GelETree *n)
 			goto just_print_a_number;
 		}
 
-		gel_output_string (gelo, "\n");
+		if (gelo->cur_line_pos != 0)
+			gel_output_string (gelo, "\n");
 
 		sep = make_sep (MAX (lend, lenn));
 
@@ -1561,7 +1583,6 @@ pretty_print_value_normal (GelOutput *gelo, GelETree *n)
 			gel_output_string (gelo, dens);
 			g_free (spacer);
 		} else {
-			gel_output_string (gelo, "\n");
 			gel_output_string (gelo, nums);
 			gel_output_string (gelo, "\n");
 			gel_output_string (gelo, sep);
@@ -1887,7 +1908,7 @@ load_compiled_fp (const char *file, FILE *fp)
 		int i;
 		GSList *li = NULL;
 		int type;
-		char *ptrptr;
+		char *ptrptr = NULL;
 
 		gel_incr_file_info();
 
@@ -2772,10 +2793,17 @@ our_chdir (const char *dirprefix, const char *dir)
 {
 	if (dirprefix == NULL ||
 	    dir[0] == G_DIR_SEPARATOR) {
-		chdir (dir);
+		errno = 0;
+		if (chdir (dir) != 0)
+			gel_errorout (_("Error changing to directory '%s': %s"), 
+				      dir, g_strerror (errno));
+
 	} else {
 		char *d = g_build_filename (dirprefix, dir, NULL);
-		chdir (d);
+		errno = 0;
+		if (chdir (d) != 0)
+			gel_errorout (_("Error changing to directory '%s': %s"), 
+				      d, g_strerror (errno));
 		g_free (d);
 	}
 }
@@ -2957,10 +2985,14 @@ do_exec_commands (const char *dirprefix)
 		ret = TRUE;
 		break;
 	case GEL_PWD:
-		getcwd (buf, sizeof (buf));
-
-		gel_output_string (main_out, buf);
-		gel_output_string (main_out, "\n");
+		errno = 0;
+		if (getcwd (buf, sizeof (buf)) == NULL) {
+			gel_errorout (_("getcwd error: %s"), 
+				      g_strerror (errno));
+		} else {
+			gel_output_string (main_out, buf);
+			gel_output_string (main_out, "\n");
+		}
 		ret = TRUE;
 		break;
 	case GEL_HELP:
@@ -3012,17 +3044,33 @@ gel_parseexp (const char *str, FILE *infile, gboolean exec_commands,
 
 	if(str) {
 		int l = strlen(str);
-		pipe(lex_fd);
+		errno = 0;
+		if G_UNLIKELY (pipe(lex_fd) != 0) {
+			gel_errorout (_("ERROR: 'pipe' failed: %s"),
+				      g_strerror (errno));
+			return NULL;
+		}
 		infile = fdopen(lex_fd[0], "r");
-		write(lex_fd[1], str, l);
-		if(str[l-1] != '\n')
-			write(lex_fd[1], "\n", 1);
+		errno = 0;
+		if (write(lex_fd[1], str, l) < l) {
+			gel_errorout (_("ERROR: 'write' possibly failed: %s"),
+				      g_strerror (errno));
+		}
+
+		if(str[l-1] != '\n') {
+			errno = 0;
+			if (write(lex_fd[1], "\n", 1) < 1) {
+				gel_errorout (_("ERROR: 'write' possibly failed: %s"),
+					      g_strerror (errno));
+			}
+		}
 		close(lex_fd[1]);
 		gel_lexer_open(infile);
 	}
 
 	gel_command = GEL_NO_COMMAND;
-	g_free (gel_command_arg); gel_command_arg = NULL;
+	g_free (gel_command_arg);
+	gel_command_arg = NULL;
 
 	lex_init = TRUE;
 	/*yydebug=TRUE;*/  /*turn debugging of parsing on here!*/
